SRF Weather
===========

Wrapper around the SRF freemium API
(https://developer.srgssr.ch/api-catalog/srf-weather/srf-weather-description)

For api definition see also
https://developer.srgssr.ch/api-catalog/srf-weather

Full documentation is available at https://srf-weather.readthedocs.io/en/latest/

